@@ -3,11 +3,11 @@ import flask
 
 
 def current_for(**values):
-    return url_for(request.endpoint, **values)
+    return url_for(endpoint=request.endpoint, **values)
 
 
 def redirect_for(endpoint, **values):
-    return redirect(url_for(endpoint, **values))
+    return redirect(url_for(endpoint=endpoint, **values))
 
 
 class Request(flask.Request):
@@ -28,4 +28,4 @@ class Glask(flask.Flask):
                                     static_folder, template_folder,
                                     instance_path, instance_relative_config)
         self.jinja_env.globals.update(current_for=current_for)
-        self.request_class = Request
\ No newline at end of file
+        self.request_class = Request
